@@ -27,9 +27,10 @@ AIR_CONDITIONER = 'air_conditioner'
 PROPANE_TANK = 'propane_tank'
 ROBOT = 'robot'
 SCENE = 'scene'
+GROUP = 'group'
 
 ALL_SUPPORTED_DEVICES = [LIGHT_BULB, BINARY_SWITCH, SENSOR_POD, LOCK, EGGTRAY,
                          GARAGE_DOOR, POWERSTRIP, SHADE, SIREN, KEY, PIGGY_BANK,
                          SMOKE_DETECTOR, THERMOSTAT, HUB, FAN, DOOR_BELL, REMOTE,
                          SPRINKLER, BUTTON, GANG, CAMERA, AIR_CONDITIONER,
-                         PROPANE_TANK, ROBOT, SCENE]
+                         PROPANE_TANK, ROBOT, SCENE, GROUP]
